var indexSectionsWithContent =
{
  0: "3abcdefghijklmnopqrstuvwy~",
  1: "abcdfhimnopstvw",
  2: "cfs",
  3: "abcdfgilmnoprstv",
  4: "abcdefghijmnopqrstuvwy~",
  5: "acdefhiklmnoprstuvw",
  6: "acdefmnpst",
  7: "acdefiprtuvw",
  8: "abcdefghiklmnoprstuvwy",
  9: "do",
  10: "cefpqst",
  11: "3abcdfghilmnopqrstuvw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Pages"
};

